pub fn run<F: FnMut(&mut Pane, &mut Scene, &mut Input, f32, f32, f32) + 'static>(
draw_fn: F,
)Expand description
Run a standalone pane application, blocking until the window is closed.
draw_fn is called every frame with (pane, scene, input, pw, ph, dt) where
pw/ph are the window pixel dimensions and dt is the frame delta in seconds.
The closure is responsible for calling run_frame which drives
widget logic, fills the scene, and presents the frame.
Panics
Panics if the event loop or window cannot be created.